@@ -20,7 +20,6 @@ class DatabaseFeatures(BaseDatabaseFeatures):
 
     supports_select_for_update_with_limit = False
 
-    # features new in Django 1.11
     supports_select_union = False
     supports_select_intersection = False
     supports_select_difference = False
@@ -55,3 +54,8 @@ class DatabaseFeatures(BaseDatabaseFeatures):
     # versa.
 
     can_introspect_json_field = False  # Django 3.1+
+
+    supports_collation_on_charfield = False  # Django 3.2+
+    supports_collation_on_textfield = False
+    supports_non_deterministic_collations = False
+    supports_expression_indexes = False
