@@ -22,13 +22,15 @@ from django.db.backends.utils import CursorWrapper as _Cursor  # for typing
 # require "simplejson" to ensure that it is available to "requests" hook.
 import simplejson  # NOQA pylint:disable=unused-import
 
+from salesforce.backend import DJANGO_32_PLUS
 import salesforce.fields
 
 log = logging.getLogger(__name__)
 
-FieldInfo = namedtuple(
+FieldInfo = namedtuple(  # type:ignore[misc]
     'FieldInfo',
     'name type_code display_size internal_size precision scale null_ok default'
+    + (' collation' if DJANGO_32_PLUS else '') +
     ' params'  # the last name 'params' is our extension for Salesforce
 )  # pylint:disable=invalid-name
 assert FieldInfo._fields[:-1] == BaseFieldInfo._fields
@@ -107,6 +109,20 @@ class DatabaseIntrospection(BaseDatabaseIntrospection):
         self._converted_lead_status = None  # type: Optional[str]
         self.is_tooling_api = False  # modified by other modules
 
+    def filter_table_list(self, table_names):
+        self._table_list_cache['sobjects'] = [
+            x for x in self.table_list_cache['sobjects'] if x['name'] in table_names
+        ]
+        self._table_names = self._table_names.intersection(table_names)
+        unknown_tables = [x for x in table_names if x not in self.connection.introspection._table_names]
+        if unknown_tables:
+            raise ValueError('These tables are not a part of the inspected Salesforce database: '
+                             '{}'.format(unknown_tables))
+
+    def reset_table_list(self, table_names):
+        self._table_list_cache = None
+        self.table_list_cache
+
     @property
     def sobjects_prefix(self) -> str:
         return 'sobjects' if not self.is_tooling_api else 'tooling/sobjects'
@@ -167,12 +183,16 @@ class DatabaseIntrospection(BaseDatabaseIntrospection):
             params['help_text'] = field['inlineHelpText']
         if field['picklistValues']:
             params['choices'] = [(x['value'], x['label']) for x in field['picklistValues'] if x['active']]
-            params['max_len'] = max(len(x['value']) for x in field['picklistValues'] if x['active'])
+            if len(repr(params['choices'])) < 4000:
+                params['max_len'] = max(len(x['value']) for x in field['picklistValues'] if x['active'])
+            else:
+                params['ref_comment'] = 'Too long choices skipped'
+                del params['choices']
         if field['type'] == 'reference' and not self.references_to(field):
             if not field['referenceTo']:
-                params['ref_comment'] = 'No Reference table'
+                params['ref_comment'] = 'No Reference to a table'
             else:
-                params['ref_comment'] = 'Invalid References: {}'.format(self.references_to(field, all=True))
+                params['ref_comment'] = 'References to missing tables: {}'.format(self.references_to(field, all=True))
         return params
 
     def references_to(self, field: Dict[str, Any], all: bool = False) -> Optional[List[str]]:
@@ -198,9 +218,10 @@ class DatabaseIntrospection(BaseDatabaseIntrospection):
                 if params['max_len'] > field['length']:
                     field['length'] = params['max_len']
                 del params['max_len']
+            optional_kw = {'collation': None} if DJANGO_32_PLUS else {}
             # We prefer "length" over "byteLength" for "internal_size".
             # (because strings have usually: byteLength == 3 * length)
-            result.append(FieldInfo(
+            result.append(FieldInfo(  # type:ignore[call-arg] # problem with a conditional type
                 field['name'],       # name,
                 field['type'],       # type_code,
                 field['length'],     # display_size,
@@ -209,7 +230,9 @@ class DatabaseIntrospection(BaseDatabaseIntrospection):
                 field['scale'],      # scale,
                 field['nillable'],   # null_ok,
                 params.get('default'),  # default
-                params,
+                # 'collation' paramater is used only in Django >= 3.2. It is before 'params', but we pass it by **kw
+                params=params,
+                **optional_kw
             ))
         return result
 
@@ -326,7 +349,7 @@ class DatabaseIntrospection(BaseDatabaseIntrospection):
 # pylint:disable=too-few-public-methods
 
 
-class SymbolicModelsName(object):
+class SymbolicModelsName:
     """A symbolic name from the `models` module.
     >>> from salesforce import models
     >>> assert models.READ_ONLY == 3
