@@ -10,8 +10,7 @@ Salesforce object manager. (like django.db.models.manager)
 
 Use a custom QuerySet to generate SOQL queries and results.
 
-This module is important for run-time, ignored in type checking and
-correct results are made by by sustomized django-stubs (django-salesforce-stubs)
+This module requires a customized package django-stubs (django-salesforce-stubs)
 """
 
 import sys
@@ -20,7 +19,7 @@ from django.db.models import manager, Model
 from django.db.models.query import QuerySet
 
 from salesforce import router
-from salesforce.backend import query, DJANGO_20_PLUS
+from salesforce.backend import query
 
 _T = TypeVar("_T", bound=Model, covariant=True)
 
@@ -31,10 +30,6 @@ class SalesforceManager(manager.Manager, Generic[_T]):
         # this is a fix for Generic type issue https://github.com/python/typing/issues/498
         __copy__ = None
 
-    if not DJANGO_20_PLUS:
-        use_for_related_fields = True
-        silence_use_for_related_fields_deprecation = True  # pylint:disable=invalid-name  # name from Django
-
     def get_queryset(self, _alias: Optional[str] = None) -> 'QuerySet[_T]':
         """
         Returns a QuerySet which access remote SF objects.
@@ -44,14 +39,14 @@ class SalesforceManager(manager.Manager, Generic[_T]):
         assert self.model is not None
         if router.is_sf_database(self.db) or alias_is_sf or is_extended_model:
             return query.SalesforceQuerySet(self.model, using=self.db)
-        return super(SalesforceManager, self).get_queryset()
+        return super().get_queryset()
 
     # def raw(self, raw_query, params=None, translations=None):
     #     if router.is_sf_database(self.db):
     #         q = models_sql_query.SalesforceRawQuery(raw_query, self.db, params)
     #         return query.SalesforceRawQuerySet(raw_query=raw_query, model=self.model, query=q,
     #                                            params=params, using=self.db)
-    #     return super(SalesforceManager, self).raw(raw_query, params=params, translations=translations)
+    #     return super().raw(raw_query, params=params, translations=translations)
 
     # methods of SalesforceQuerySet on a SalesfroceManager
 
