@@ -7,7 +7,6 @@ from django.conf import settings
 from django.db.models import Count, Model
 from django.db.models.sql import Query, RawQuery, constants
 
-from salesforce.backend import DJANGO_20_PLUS
 from salesforce.dbapi.driver import arg_to_soql
 
 _T = TypeVar("_T", bound=Model, covariant=True)
@@ -26,7 +25,7 @@ class SalesforceRawQuery(RawQuery):
 #         if self.cursor.rowcount > 0:
 #             return [converter(col) for col in self.cursor.first_row.keys() if col != 'attributes']
 #         # TODO hy: A more general fix is desirable with rewriting more code.
-#         return ['Id']  # originally [SF_PK] before Django 1.8.4
+#         return ['Id']
 #
 #     def _execute_query(self):
 #         self.cursor = connections[self.using].cursor()
@@ -37,7 +36,7 @@ class SalesforceRawQuery(RawQuery):
 #         return "<SalesforceRawQuery: %s; %r>" % (self.sql, tuple(self.params))
 #
 #     def __iter__(self):
-#         for row in super(SalesforceRawQuery, self).__iter__():
+#         for row in super().__iter__():
 #             yield [row[k] for k in self.get_columns()]
 
 
@@ -53,7 +52,7 @@ class SalesforceQuery(Query, Generic[_T]):
     Override aggregates.
     """
     def __init__(self, model: Optional[Type[_T]], *args, **kwargs) -> None:
-        super(SalesforceQuery, self).__init__(model, *args, **kwargs)
+        super().__init__(model, *args, **kwargs)
         self.max_depth = 1
         self.sf_params = SfParams()  # paramaters for Salesforce query instead of transaction control
 
@@ -74,13 +73,7 @@ class SalesforceQuery(Query, Generic[_T]):
         return self.get_compiler(sf_alias).as_sql()
 
     def clone(self, klass=None, memo=None) -> 'SalesforceQuery[_T]':  # pylint: disable=arguments-differ
-        if DJANGO_20_PLUS:
-            query = cast(SalesforceQuery, Query.clone(self))
-        else:
-            # pylint: disable=too-many-function-args
-            query = cast(SalesforceQuery, Query.clone(self, klass, memo))  # type: ignore[call-arg]  # noqa
-            query.sf_params = self.sf_params
-        return query
+        return cast(SalesforceQuery, Query.clone(self))
 
     def sf(self,
            query_all: Optional[bool] = None,
@@ -123,11 +116,10 @@ class SalesforceQuery(Query, Generic[_T]):
         return bool(compiler.execute_sql(constants.SINGLE))
 
     def get_count(self, using: str) -> int:
-        # TODO maybe can be removed soon
         """
         Performs a COUNT() query using the current filter constraints.
         """
-        # customized because "Count('*')" is not possbel wit Salesforce and also not "__" in an alias
+        # customized because "Count('*')" is not possible with Salesforce and also not "__" in an alias
         obj = self.clone()
         obj.add_annotation(Count('pk'), alias='x_sf_count', is_summary=True)  # pylint: disable=no-member
         number = obj.get_aggregation(using, ['x_sf_count'])['x_sf_count']  # type: Optional[int] # pylint: disable=no-member # noqa
