@@ -86,7 +86,7 @@ class SalesforceAutoField(fields.AutoField):
             # with the same default SalesforceAutoField. Therefore the second should be
             # ignored.
             return
-        super(SalesforceAutoField, self).contribute_to_class(cls, name, **kwargs)
+        super().contribute_to_class(cls, name, **kwargs)
         cls._meta.auto_field = self
 
 
@@ -110,7 +110,7 @@ class SfField(models.Field):
         self.sf_namespace = ''
         if kwargs.get('default') is DEFAULTED_ON_CREATE:
             kwargs['default'] = DefaultedOnCreate(internal_type=self.get_internal_type())
-        super(SfField, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def get_attname_column(self) -> Tuple[str, str]:
         """
@@ -138,10 +138,8 @@ class SfField(models.Field):
                 column = self.sf_namespace + column + '__c'
         return attname, column
 
-    def contribute_to_class(self, cls, name, private_only=False, **kwargs):
-        # More arguments are in Django 1.11 than in Django 2.0, therefore we use the universal **kwargs
-        # pylint:disable=arguments-differ
-        super(SfField, self).contribute_to_class(cls, name, private_only=private_only, **kwargs)
+    def contribute_to_class(self, cls, name, private_only=False):
+        super().contribute_to_class(cls, name, private_only=private_only)
         if self.sf_custom is None and hasattr(cls._meta, 'sf_custom'):
             # Only custom fields in models explicitly marked by
             # Meta custom=True are recognized automatically - for
@@ -204,15 +202,14 @@ class DecimalField(SfField, models.DecimalField):
     def to_python(self, value):
         if str(value) == '':
             return value
-        ret = super(DecimalField, self).to_python(value)
+        ret = super().to_python(value)
         if ret is not None and self.decimal_places == 0:
             # this is because Salesforce has no numeric integer type
             if ret == int(ret):
                 ret = Decimal(int(ret))
         return ret
 
-    # parameter "context" is for Django <= 1.11 (the same is in more classes here)
-    def from_db_value(self, value, expression, connection, context=None):
+    def from_db_value(self, value, expression, connection):
         # pylint:disable=unused-argument
         # TODO refactor and move to the driver like in other backends
         if isinstance(value, float):
@@ -235,7 +232,7 @@ class BooleanField(SfField, models.BooleanField):
     a default value. Implicit default is False if not specified.
     """
     def __init__(self, default=False, **kwargs):
-        super(BooleanField, self).__init__(default=default, **kwargs)
+        super().__init__(default=default, **kwargs)
 
 
 class DateTimeField(SfField, models.DateTimeField):
@@ -245,7 +242,7 @@ class DateTimeField(SfField, models.DateTimeField):
 class DateField(SfField, models.DateField):
     """DateField with sf_read_only attribute for Salesforce."""
 
-    def from_db_value(self, value, expression, connection, context=None):
+    def from_db_value(self, value, expression, connection):
         # pylint:disable=unused-argument
         return self.to_python(value)
 
@@ -253,7 +250,7 @@ class DateField(SfField, models.DateField):
 class TimeField(SfField, models.TimeField):
     """TimeField with sf_read_only attribute for Salesforce."""
 
-    def from_db_value(self, value, expression, connection, context=None):
+    def from_db_value(self, value, expression, connection):
         # pylint:disable=unused-argument
         return self.to_python(value)
 
