@@ -13,6 +13,7 @@ import logging
 import os
 import re
 import warnings
+from typing import Any, cast, List, TypeVar
 
 import pytz
 from django.conf import settings
@@ -20,7 +21,6 @@ from django.db import connections
 from django.db.models import Q, Avg, Count, Sum, Min, Max, Model, query as models_query
 from django.test import TestCase
 from django.utils import timezone
-from typing import Any, cast, List, TypeVar
 
 import salesforce
 from salesforce import router
@@ -176,7 +176,7 @@ class BasicSOQLRoTest(TestCase, LazyTestMixin):
             with self.lazy_assert_n_requests(1):
                 qs = Contact.objects.filter(account__Name='sf_test account').select_related('account')
                 contacts = list(qs)
-            with self.lazy_assert_n_requests(0):  # this fails in Django 2.0 - not cached
+            with self.lazy_assert_n_requests(0):
                 [x.account.Name for x in contacts]
             self.assertGreaterEqual(len(contacts), 1)
             self.lazy_check()
@@ -330,7 +330,8 @@ class BasicSOQLRoTest(TestCase, LazyTestMixin):
         finally:
             contact.delete()
         # Verify that an explicit value is possible for this field.
-        other_user_obj = User.objects.exclude(Username=current_user).filter(IsActive=True)[0]
+        other_user_obj = (User.objects.exclude(Username=current_user)
+                          .filter(IsActive=True, UserType='Standard')[0])
         contact = Contact(first_name='sf_test', last_name='your',
                           owner=other_user_obj)
         contact.save()
@@ -897,7 +898,9 @@ class BasicSOQLRoTest(TestCase, LazyTestMixin):
         salesforce.auth.oauth_data[sf_alias]['access_token'] = 'something invalid/expired'
         with self.assertWarns(SalesforceWarning) as cm:
             Contact(pk=contact_id).delete()
-            self.assertIn('ENTITY_IS_DELETED', cm.warnings[0].message.args[0])
+            message = cm.warnings[0].message
+            assert isinstance(message, SalesforceWarning)
+            self.assertIn('ENTITY_IS_DELETED', message.args[0])
         with self.assertWarns(SalesforceWarning) as cm:
             # Id of completely deleted item or fake but valid item.
             Contact(pk='003000000000000AAA').delete()
