@@ -75,6 +75,10 @@ def run():
         'ObjectSearchSetting', 'OpportunityInsightsSettings',
         'OpportunityListFieldsLabelMapping', 'OpportunityScoreSettings',
         'OrderManagementSettings', 'StandardAction', 'StandardValueSet',
+        # in API 50.0 Winter'20
+        'InventorySettings', 'SecuritySettings',
+        # in API 51.0 Spring '21
+        'EmployeeUserSettings',
     }
     problematic_write = {
         # any SalesforceError
@@ -98,6 +102,10 @@ def run():
         'SurveySettings', 'SystemNotificationSettings', 'Territory2Settings',
         'TrialOrgSettings', 'User', 'UserEngagementSettings', 'UserInterfaceSettings',
         'UserManagementSettings', 'WebToXSettings', 'WorkDotComSettings',
+
+        # in API 50.0 Winter'20
+        'ExternalServicesSettings', 'RecommendationBuilderSettings',
+
         # ExpirationDate must be in the future.
         'TraceFlag',
         # silently not updated
@@ -147,11 +155,11 @@ def run():
                     obj.save(force_update=True)
                 except SalesforceError as exc:
                     new_problematic.append(db_table)
-                    stderr.write("\n************** SalesforceError %s %s\n" % (db_table, exc))
+                    stderr.write("\n************** write SalesforceError %s %s\n" % (db_table, exc))
                     n_write_errors += 1
                 except (TypeError, NotImplementedError) as exc:
                     new_problematic.append(db_table)
-                    stderr.write("\n************** %s %s %s\n" % (exc.__class__.__name__, db_table, exc))
+                    stderr.write("\n************** write %s %s %s\n" % (exc.__class__.__name__, db_table, exc))
                     n_write_errors += 1
                 else:
                     # object 'Topic' doesn't have the attribute 'last_modified_date'
@@ -165,7 +173,8 @@ def run():
     if new_problematic:
         print("\nnew_problematic:\n%r\n" % new_problematic)
     n_tables = len(sf.introspection.table_list_cache['sobjects'])
-    print('Result: {n_tables} tables, {n_read} reads tried, {n_no_data} no data, '
+    print('Tooling api results:')
+    print('  {n_tables} tables, {n_read} reads tried, {n_no_data} no data, '
           '{n_read_errors} read errors, {n_write} writes tried, {n_write_errors} write errors'
           .format(n_tables=n_tables, n_read=n_read, n_no_data=n_no_data,
                   n_read_errors=n_read_errors, n_write=n_write, n_write_errors=n_write_errors))
